/*
 * EtherPix library
 *
 * Copyright 2010-2017 Stefan Schuermans <stefan schuermans info>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3 of the License.
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef ETP_CONSTANTS_H
#define ETP_CONSTANTS_H

/* EtherPix hardware constants */
#define ETP_DISTRI_MAX_CNT (4096) /**< maximum number of distributors
                                   *   that can be in the system,
                                   *   number of distributor addresses
                                   *   available */
#define ETP_OUTPUT_MAX_CNT (128)  /**< maximum number of outputs per
                                   *   distributor */
#define ETP_PIXEL_MAX_CNT  (1024) /**< maximum number of pixels that can
                                   *   be connected to an output of a
                                   *   distributor */

/* MCUF constants */
#define ETP_MCUF_HDR ("\x23\x54\x26\x66" \
                      "\x00\x00\x00\x00" \
                      "\x00\x03\x00\xFF")     /**< data of MCUF header */
#define ETP_MCUF_HDR_LEN              (12)    /**< length of MCUF header */
#define ETP_MCUF_HDR_OFS_OUTPUTS_U16  (4)     /**< offset of output count
                                               *   in MCUF data */
#define ETP_MCUF_HDR_OFS_PIXELS_U16   (6)     /**< offset of pixel count
                                               *   in MCUF data */
#define ETP_MCUF_MAX_FRAME_INTERVAL_MS (1000) /**< maximum interval between
                                                   two MCUF frames */

/* fixed settings constants */
#define ETP_DEST_IP_BASE (0x0A465000) /**< base IP address of distributors,
                                       *   i.e. IP address of distributor 0,
                                       *   10.70.80.0 */
#define ETP_DEST_IP_STEP (0x00000001) /**< IP adress step of distributors,
                                       *   i.e. increment of IP address for
                                       *   every distributor address,
                                       *   0.0.0.1 */
#define ETP_DEST_PORT    (2323)       /**< UDP port the distributors
                                       *   listen on */

/* default settings constants */
#define ETP_BIND_IP   (0x00000000) /**< default IP to bind to
                                    *   (first IP octect in LSB) */
#define ETP_BIND_PORT (0)          /**< default port to bind to */


#endif /* #ifndef ETP_CONSTANTS_H */

